@@ -69,24 +69,24 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_route53
-import constructs
+import aws_cdk.aws_route53 as _aws_cdk_aws_route53_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class HugoDeploy(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="cdk-hugo-deploy.HugoDeploy",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         domain_name: builtins.str,
         public_dir: builtins.str,
         region: typing.Optional[builtins.str] = None,
-        zone: typing.Optional[aws_cdk.aws_route53.HostedZone] = None,
+        zone: typing.Optional[_aws_cdk_aws_route53_ceddda9d.HostedZone] = None,
     ) -> None:
         '''
         :param scope: -
@@ -97,7 +97,7 @@ class HugoDeploy(
         :param zone: Zone the Domain Name is created in.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HugoDeploy.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__e03820b2549e7ec849582d7a418c4d7083c889cc04af621d01d3293835348c33)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = HugoDeployProps(
@@ -139,7 +139,7 @@ class HugoDeployProps:
         domain_name: builtins.str,
         public_dir: builtins.str,
         region: typing.Optional[builtins.str] = None,
-        zone: typing.Optional[aws_cdk.aws_route53.HostedZone] = None,
+        zone: typing.Optional[_aws_cdk_aws_route53_ceddda9d.HostedZone] = None,
     ) -> None:
         '''
         :param domain_name: Domain name of the site deploying to. You should already have a hosted zone in the account you're deploying to with this domain name
@@ -148,12 +148,12 @@ class HugoDeployProps:
         :param zone: Zone the Domain Name is created in.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(HugoDeployProps.__init__)
+            type_hints = typing.get_type_hints(_typecheckingstub__271c7d0295ae9e51ecb9baa9f1bb05877c6312f1b12ff88b745fac6f0d541f19)
             check_type(argname="argument domain_name", value=domain_name, expected_type=type_hints["domain_name"])
             check_type(argname="argument public_dir", value=public_dir, expected_type=type_hints["public_dir"])
             check_type(argname="argument region", value=region, expected_type=type_hints["region"])
             check_type(argname="argument zone", value=zone, expected_type=type_hints["zone"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "domain_name": domain_name,
             "public_dir": public_dir,
         }
@@ -192,10 +192,10 @@ class HugoDeployProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def zone(self) -> typing.Optional[aws_cdk.aws_route53.HostedZone]:
+    def zone(self) -> typing.Optional[_aws_cdk_aws_route53_ceddda9d.HostedZone]:
         '''Zone the Domain Name is created in.'''
         result = self._values.get("zone")
-        return typing.cast(typing.Optional[aws_cdk.aws_route53.HostedZone], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_route53_ceddda9d.HostedZone], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -215,3 +215,25 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__e03820b2549e7ec849582d7a418c4d7083c889cc04af621d01d3293835348c33(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    domain_name: builtins.str,
+    public_dir: builtins.str,
+    region: typing.Optional[builtins.str] = None,
+    zone: typing.Optional[_aws_cdk_aws_route53_ceddda9d.HostedZone] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__271c7d0295ae9e51ecb9baa9f1bb05877c6312f1b12ff88b745fac6f0d541f19(
+    *,
+    domain_name: builtins.str,
+    public_dir: builtins.str,
+    region: typing.Optional[builtins.str] = None,
+    zone: typing.Optional[_aws_cdk_aws_route53_ceddda9d.HostedZone] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
